@@ -2,10 +2,9 @@ import math
 from itertools import product
 import warnings
 import numpy as np
-import scipy as sp
 from matplotlib import colors
 
-from spatialmath import base as smbase
+from spatialmath import base as smb
 
 try:
     import matplotlib.pyplot as plt
@@ -142,10 +141,10 @@ def plot_point(pos, marker="bs", text=None, ax=None, textargs=None, textcolor=No
         # [(x,y), (x,y), ...]
         # [xlist, ylist]
         # [xarray, yarray]
-        if smbase.islistof(pos, (tuple, list)):
+        if smb.islistof(pos, (tuple, list)):
             x = [z[0] for z in pos]
             y = [z[1] for z in pos]
-        elif smbase.islistof(pos, np.ndarray):
+        elif smb.islistof(pos, np.ndarray):
             x = pos[0]
             y = pos[1]
         else:
@@ -231,7 +230,7 @@ def plot_homline(lines, *args, ax=None, xlim=None, ylim=None, **kwargs):
 
     # if lines.ndim == 1:
     #     lines = lines.
-    lines = smbase.getmatrix(lines, (3, None))
+    lines = smb.getmatrix(lines, (3, None))
 
     handles = []
     for line in lines.T:  # for each column
@@ -323,7 +322,7 @@ def plot_box(
     """
 
     if wh is not None:
-        if smbase.isscalar(wh):
+        if smb.isscalar(wh):
             w, h = wh, wh
         else:
             w, h = wh
@@ -463,7 +462,9 @@ def _render2D(vertices, pose=None, filled=False, color=None, ax=None, fmt=(), **
         r = plt.Polygon(vertices.T, closed=True, **kwargs)
         ax.add_patch(r)
     else:
-        r = plt.plot(vertices[0, :], vertices[1, :], *fmt, color=color, **kwargs)
+        if color is not None:
+            kwargs["color"] = color
+        r = plt.plot(vertices[0, :], vertices[1, :], *fmt, **kwargs)
     return r
 
 
@@ -528,7 +529,7 @@ def plot_circle(
         >>> plot_circle(2, 'b--')  # blue dashed circle
         >>> plot_circle(0.5, filled=True, facecolor='y')  # yellow filled circle
     """
-    centres = smbase.getmatrix(centre, (2, None))
+    centres = smb.getmatrix(centre, (2, None))
 
     ax = axes_logic(ax, 2)
     handles = []
@@ -574,6 +575,8 @@ def ellipse(E, centre=(0, 0), scale=1, confidence=None, resolution=40, inverted=
         so to avoid inverting ``E`` twice to compute the ellipse, we flag that
         the inverse is provided using ``inverted``.
     """
+    from scipy.linalg import sqrtm
+
     if E.shape != (2, 2):
         raise ValueError("ellipse is defined by a 2x2 matrix")
 
@@ -590,7 +593,7 @@ def ellipse(E, centre=(0, 0), scale=1, confidence=None, resolution=40, inverted=
     if not inverted:
         E = np.linalg.inv(E)
 
-    e = s * sp.linalg.sqrtm(E) @ xy + np.array(centre, ndmin=2).T
+    e = s * sqrtm(E) @ xy + np.array(centre, ndmin=2).T
     return e
 
 
@@ -724,7 +727,7 @@ def plot_sphere(radius, centre=(0, 0, 0), pose=None, resolution=50, ax=None, **k
     """
     ax = axes_logic(ax, 3)
 
-    centre = smbase.getmatrix(centre, (3, None))
+    centre = smb.getmatrix(centre, (3, None))
 
     handles = []
     for c in centre.T:
@@ -766,6 +769,8 @@ def ellipsoid(
 
     :seealso: :func:`plot_ellipsoid`, :func:`~matplotlib.pyplot.plot_surface`, :func:`~matplotlib.pyplot.plot_wireframe`
     """
+    from scipy.linalg import sqrtm
+
     if E.shape != (3, 3):
         raise ValueError("ellipsoid is defined by a 3x3 matrix")
 
@@ -782,7 +787,7 @@ def ellipsoid(
 
     x, y, z = sphere()  # unit sphere
     e = (
-        s * sp.linalg.sqrtm(E) @ np.array([x.flatten(), y.flatten(), z.flatten()])
+        s * sqrtm(E) @ np.array([x.flatten(), y.flatten(), z.flatten()])
         + np.c_[centre].T
     )
     return e[0, :].reshape(x.shape), e[1, :].reshape(x.shape), e[2, :].reshape(x.shape)
@@ -893,7 +898,7 @@ def plot_cylinder(
 
     :seealso: :func:`~matplotlib.pyplot.plot_surface`, :func:`~matplotlib.pyplot.plot_wireframe`
     """
-    if smbase.isscalar(height):
+    if smb.isscalar(height):
         height = [0, height]
 
     ax = axes_logic(ax, 3)
@@ -1033,7 +1038,7 @@ def plot_cuboid(
     vertices = vertices.T
 
     if pose is not None:
-        vertices = smbase.homtrans(pose.A, vertices)
+        vertices = smb.homtrans(pose.A, vertices)
 
     ax = axes_logic(ax, 3)
     # plot sides
@@ -1315,7 +1320,7 @@ def expand_dims(dim=None, nd=2):
         * [A,B] -> [A, B, A, B, A, B]
         * [A,B,C,D,E,F] -> [A, B, C, D, E, F]
     """
-    dim = smbase.getvector(dim)
+    dim = smb.getvector(dim)
 
     if nd == 2:
         if len(dim) == 1:
@@ -1362,24 +1367,10 @@ def isnotebook():
 
 if __name__ == "__main__":
     import pathlib
-
-
-    plotvol2(5)
-    # plot_box(ltrb=[-1, 4, 2, 2], color='r', linewidth=2)
-    # plot_box(lbrt=[-1, 2, 2, 4], color='k', linestyle='--', linewidth=4)
-    # plot_box(lbwh=[2, -2, 2, 3], color='k', linewidth=2)
-    # plot_box(centre=(-2, -1), wh=2, color='b', linewidth=2)
-    # plot_box(centre=(-2, -1), wh=(1,3), color='g', linewidth=2)
-    # plt.grid(True)
-    # plt.show(block=True)
-
-    # plt.imshow(np.eye(200))
-    # umin, umax, vmin, vmax = 23, 166, 110, 212
-    # plot_box(l=umin, r=umax, t=vmin, b=vmax, color="g")
-
-    plot_circle(1, (2,3), resolution=3, filled=False)
-    plt.show(block=True)
     
+    E = np.array([[1, 1], [1, 2]]);
+    plot_ellipse(E, centre=[0, 0])
+
     exec(
         open(
             pathlib.Path(__file__).parent.parent.parent.absolute()
