@@ -17,8 +17,7 @@ tuple, numpy array, numpy row vector or numpy column vector.
 import sys
 import math
 import numpy as np
-import scipy.linalg
-from spatialmath import base
+import spatialmath.base as smb
 
 _eps = np.finfo(np.float64).eps
 
@@ -52,9 +51,9 @@ def rot2(theta, unit="rad"):
         >>> rot2(0.3)
         >>> rot2(45, 'deg')
     """
-    theta = base.getunit(theta, unit)
-    ct = base.sym.cos(theta)
-    st = base.sym.sin(theta)
+    theta = smb.getunit(theta, unit)
+    ct = smb.sym.cos(theta)
+    st = smb.sym.sin(theta)
     # fmt: off
     R = np.array([
         [ct, -st],
@@ -94,7 +93,7 @@ def trot2(theta, unit="rad", t=None):
     """
     T = np.pad(rot2(theta, unit), (0, 1), mode="constant")
     if t is not None:
-        T[:2, 2] = base.getvector(t, 2, "array")
+        T[:2, 2] = smb.getvector(t, 2, "array")
     T[2, 2] = 1  # integer to be symbolic friendly
     return T
 
@@ -121,7 +120,7 @@ def xyt2tr(xyt, unit="rad"):
 
     :seealso: tr2xyt
     """
-    xyt = base.getvector(xyt, 3)
+    xyt = smb.getvector(xyt, 3)
     T = np.pad(rot2(xyt[2], unit), (0, 1), mode="constant")
     T[:2, 2] = xyt[0:2]
     T[2, 2] = 1.0
@@ -211,13 +210,13 @@ def transl2(x, y=None):
         function.
     """
 
-    if base.isscalar(x) and base.isscalar(y):
+    if smb.isscalar(x) and smb.isscalar(y):
         # (x, y) -> SE(2)
         t = np.r_[x, y]
-    elif base.isvector(x, 2):
+    elif smb.isvector(x, 2):
         # R2 -> SE(2)
-        t = base.getvector(x, 2)
-    elif base.ismatrix(x, (3, 3)):
+        t = smb.getvector(x, 2)
+    elif smb.ismatrix(x, (3, 3)):
         # SE(2) -> R2
         return x[:2, 2]
     else:
@@ -264,7 +263,7 @@ def ishom2(T, check=False):
         and T.shape == (3, 3)
         and (
             not check
-            or (base.isR(T[:2, :2]) and np.all(T[2, :] == np.array([0, 0, 1])))
+            or (smb.isR(T[:2, :2]) and np.all(T[2, :] == np.array([0, 0, 1])))
         )
     )
 
@@ -298,7 +297,7 @@ def isrot2(R, check=False):
     :seealso: isR, ishom2, isrot
     """
     return (
-        isinstance(R, np.ndarray) and R.shape == (2, 2) and (not check or base.isR(R))
+        isinstance(R, np.ndarray) and R.shape == (2, 2) and (not check or smb.isR(R))
     )
 
 
@@ -340,7 +339,7 @@ def trinv2(T):
     return Ti
 
 
-def trlog2(T, check=True, twist=False):
+def trlog2(T, check=True, twist=False, tol=10):
     """
     Logarithm of SO(2) or SE(2) matrix
 
@@ -350,6 +349,8 @@ def trlog2(T, check=True, twist=False):
     :type check: bool
     :param twist: return a twist vector instead of matrix [default]
     :type twist: bool
+    :param tol: Tolerance in units of eps for zero-rotation case, defaults to 10
+    :type: float
     :return: logarithm
     :rtype: ndarray(3,3) or ndarray(3); or ndarray(2,2) or ndarray(1)
     :raises ValueError: bad argument
@@ -374,31 +375,43 @@ def trlog2(T, check=True, twist=False):
         >>> trlog2(rot2(0.3))
         >>> trlog2(rot2(0.3), twist=True)
 
-    :seealso: :func:`~trexp`, :func:`~spatialmath.base.transformsNd.vex`,
-              :func:`~spatialmath.base.transformsNd.vexa`
+    :seealso: :func:`~trexp`, :func:`~spatialmath.smb.transformsNd.vex`,
+              :func:`~spatialmath.smb.transformsNd.vexa`
     """
 
     if ishom2(T, check=check):
         # SE(2) matrix
 
-        if base.iseye(T):
+        if smb.iseye(T, tol):
             # is identity matrix
             if twist:
                 return np.zeros((3,))
             else:
                 return np.zeros((3, 3))
         else:
-            if twist:
-                return base.vexa(scipy.linalg.logm(T))
+            st = T[1,0]
+            ct = T[0,0]
+            theta = math.atan(st / ct)
+            if abs(theta) < tol * _eps:
+                tr = T[:2, 2].flatten()
             else:
-                return scipy.linalg.logm(T)
+                V = np.array([[st, -(1-ct)], [1-ct, st]])
+                tr = (np.linalg.inv(V) @ T[:2, 2]) * theta
+            if twist:
+                return np.hstack([tr, theta])
+            else:
+                return np.block([
+                    [smb.skew(theta), tr[:, np.newaxis]], 
+                    [np.zeros((1,3))]
+                ])
 
     elif isrot2(T, check=check):
         # SO(2) rotation matrix
+        theta = math.atan(T[1,0] / T[0,0])
         if twist:
-            return base.vex(scipy.linalg.logm(T))
+            return theta
         else:
-            return scipy.linalg.logm(T)
+            return smb.skew(theta)
     else:
         raise ValueError("Expect SO(2) or SE(2) matrix")
 
@@ -466,55 +479,55 @@ def trexp2(S, theta=None, check=True):
     :seealso: trlog, trexp2
     """
 
-    if base.ismatrix(S, (3, 3)) or base.isvector(S, 3):
+    if smb.ismatrix(S, (3, 3)) or smb.isvector(S, 3):
         # se(2) case
-        if base.ismatrix(S, (3, 3)):
+        if smb.ismatrix(S, (3, 3)):
             # augmentented skew matrix
-            if check and not base.isskewa(S):
+            if check and not smb.isskewa(S):
                 raise ValueError("argument must be a valid se(2) element")
-            tw = base.vexa(S)
+            tw = smb.vexa(S)
         else:
             # 3 vector
-            tw = base.getvector(S)
+            tw = smb.getvector(S)
 
-        if base.iszerovec(tw):
+        if smb.iszerovec(tw):
             return np.eye(3)
 
         if theta is None:
-            (tw, theta) = base.unittwist2_norm(tw)
-        elif not base.isunittwist2(tw):
+            (tw, theta) = smb.unittwist2_norm(tw)
+        elif not smb.isunittwist2(tw):
             raise ValueError("If theta is specified S must be a unit twist")
 
         t = tw[0:2]
         w = tw[2]
 
-        R = base.rodrigues(w, theta)
+        R = smb.rodrigues(w, theta)
 
-        skw = base.skew(w)
+        skw = smb.skew(w)
         V = (
             np.eye(2) * theta
             + (1.0 - math.cos(theta)) * skw
             + (theta - math.sin(theta)) * skw @ skw
         )
 
-        return base.rt2tr(R, V @ t)
+        return smb.rt2tr(R, V @ t)
 
-    elif base.ismatrix(S, (2, 2)) or base.isvector(S, 1):
+    elif smb.ismatrix(S, (2, 2)) or smb.isvector(S, 1):
         # so(2) case
-        if base.ismatrix(S, (2, 2)):
+        if smb.ismatrix(S, (2, 2)):
             # skew symmetric matrix
-            if check and not base.isskew(S):
+            if check and not smb.isskew(S):
                 raise ValueError("argument must be a valid so(2) element")
-            w = base.vex(S)
+            w = smb.vex(S)
         else:
             # 1 vector
-            w = base.getvector(S)
+            w = smb.getvector(S)
 
-        if theta is not None and not base.isunitvec(w):
+        if theta is not None and not smb.isunitvec(w):
             raise ValueError("If theta is specified S must be a unit twist")
 
         # do Rodrigues' formula for rotation
-        return base.rodrigues(w, theta)
+        return smb.rodrigues(w, theta)
     else:
         raise ValueError(" First argument must be SO(2), 1-vector, SE(2) or 3-vector")
 
@@ -526,7 +539,7 @@ def adjoint2(T):
         return np.identity(2)
     elif T.shape == (3, 3):
         # SE(2) adjoint
-        (R, t) = base.tr2rt(T)
+        (R, t) = smb.tr2rt(T)
         # fmt: off
         return np.block([
                 [R, np.c_[t[1], -t[0]].T], 
@@ -567,7 +580,7 @@ def tr2jac2(T):
         raise ValueError("expecting an SE(2) matrix")
 
     J = np.eye(3, dtype=T.dtype)
-    J[:2, :2] = base.t2r(T)
+    J[:2, :2] = smb.t2r(T)
     return J
 
 
@@ -608,10 +621,10 @@ def trinterp2(start, end, s=None):
         >>> trinterp2(None, T2, 1)
         >>> trinterp2(None, T2, 0.5)
 
-    :seealso: :func:`~spatialmath.base.transforms3d.trinterp`
+    :seealso: :func:`~spatialmath.smb.transforms3d.trinterp`
 
     """
-    if base.ismatrix(end, (2, 2)):
+    if smb.ismatrix(end, (2, 2)):
         # SO(2) case
         if start is None:
             # 	TRINTERP2(T, s)
@@ -630,7 +643,7 @@ def trinterp2(start, end, s=None):
             th = th0 * (1 - s) + s * th1
 
         return rot2(th)
-    elif base.ismatrix(end, (3, 3)):
+    elif smb.ismatrix(end, (3, 3)):
         if start is None:
             # 	TRINTERP2(T, s)
 
@@ -653,7 +666,7 @@ def trinterp2(start, end, s=None):
             pr = p0 * (1 - s) + s * p1
             th = th0 * (1 - s) + s * th1
 
-        return base.rt2tr(rot2(th), pr)
+        return smb.rt2tr(rot2(th), pr)
     else:
         return ValueError("Argument must be SO(2) or SE(2)")
 
@@ -782,7 +795,6 @@ def points2tr2(p1, p2):
 # https://github.com/1988kramer/intel_dataset/blob/master/scripts/Align2D.py
 # hack below to use points2tr above
 # use ClayFlannigan's improved data association
-from scipy.spatial import KDTree
 
 # reference or target 2xN
 # source  2xN
@@ -810,6 +822,8 @@ from scipy.spatial import KDTree
 #   min_delta_err: float, minimum change in alignment error
 def ICP2d(reference, source, T=None, max_iter=20, min_delta_err=1e-4):
 
+    from scipy.spatial import KDTree
+
     mean_sq_error = 1.0e6 # initialize error as large number
     delta_err = 1.0e6    # change in error (used in stopping condition)
     num_iter = 0         # number of iterations
@@ -930,7 +944,7 @@ def _AlignSVD(source, reference):
     # translation is the difference between the point clound centroids
     t = ref_centroid - R @ src_centroid
 
-    return base.rt2tr(R, t)
+    return smb.rt2tr(R, t)
 
 def trplot2(
     T,
@@ -1035,11 +1049,11 @@ def trplot2(
 
     # check input types
     if isrot2(T, check=True):
-        T = base.r2t(T)
+        T = smb.r2t(T)
     elif not ishom2(T, check=True):
         raise ValueError("argument is not valid SE(2) matrix")
 
-    ax = base.axes_logic(ax, 2)
+    ax = smb.axes_logic(ax, 2)
 
     try:
         if not ax.get_xlabel():
@@ -1053,7 +1067,7 @@ def trplot2(
         ax.set_aspect("equal")
 
     if dims is not None:
-        ax.axis(base.expand_dims(dims))
+        ax.axis(smb.expand_dims(dims))
     elif not hasattr(ax, "_plotvol"):
         ax.autoscale(enable=True, axis="both")
 
@@ -1172,7 +1186,7 @@ def tranimate2(T, **kwargs):
             tranimate2(transl(1,2)@trot2(1), frame='A', arrow=False, dims=[0, 5])
             tranimate2(transl(1,2)@trot2(1), frame='A', arrow=False, dims=[0, 5], movie='spin.mp4')
     """
-    anim = base.animate.Animate2(**kwargs)
+    anim = smb.animate.Animate2(**kwargs)
     try:
         del kwargs["dims"]
     except KeyError:
