@@ -17,7 +17,6 @@ tuple, numpy array, numpy row vector or numpy column vector.
 import sys
 import math
 import numpy as np
-import scipy as sp
 from collections.abc import Iterable
 
 from spatialmath import base as smb
@@ -324,6 +323,8 @@ def ishom(T, check=False, tol=100):
     :type T: numpy(4,4)
     :param check: check validity of rotation submatrix
     :type check: bool
+    :param tol: Tolerance in units of eps for rotation submatrix check, defaults to 100
+    :type: float
     :return: whether matrix is an SE(3) homogeneous transformation matrix
     :rtype: bool
 
@@ -366,6 +367,8 @@ def isrot(R, check=False, tol=100):
     :type R: numpy(3,3)
     :param check: check validity of rotation submatrix
     :type check: bool
+    :param tol: Tolerance in units of eps for rotation matrix test, defaults to 100
+    :type: float
     :return: whether matrix is an SO(3) rotation matrix
     :rtype: bool
 
@@ -1143,7 +1146,7 @@ def tr2rpy(T, unit="rad", order="zyx", check=False):
 
 
 # ---------------------------------------------------------------------------------------#
-def trlog(T, check=True, twist=False):
+def trlog(T, check=True, twist=False, tol=10):
     """
     Logarithm of SO(3) or SE(3) matrix
 
@@ -1153,6 +1156,8 @@ def trlog(T, check=True, twist=False):
     :type check: bool
     :param twist: return a twist vector instead of matrix [default]
     :type twist: bool
+    :param tol: Tolerance in units of eps for zero-rotation case, defaults to 10
+    :type: float
     :return: logarithm
     :rtype: ndarray(4,4) or ndarray(3,3)
     :raises ValueError: bad argument
@@ -1180,10 +1185,10 @@ def trlog(T, check=True, twist=False):
     :seealso: :func:`~trexp` :func:`~spatialmath.smb.transformsNd.vex` :func:`~spatialmath.smb.transformsNd.vexa`
     """
 
-    if ishom(T, check=check):
+    if ishom(T, check=check, tol=10):
         # SE(3) matrix
 
-        if smb.iseye(T):
+        if smb.iseye(T, tol=tol):
             # is identity matrix
             if twist:
                 return np.zeros((6,))
@@ -1222,7 +1227,7 @@ def trlog(T, check=True, twist=False):
                 return np.zeros((3,))
             else:
                 return np.zeros((3, 3))
-        elif abs(np.trace(R) + 1) < 100 * _eps:
+        elif abs(np.trace(R) + 1) < tol * _eps:
             # check for trace = -1
             #   rotation by +/- pi, +/- 3pi etc.
             diagonal = R.diagonal()
@@ -2227,7 +2232,9 @@ def rotvelxform(𝚪, inverse=False, full=False, representation="rpy/xyz"):
             )
 
     if full:
-        return sp.linalg.block_diag(np.eye(3, 3), A)
+        AA = np.eye(6)
+        AA[3:, 3:] = A
+        return AA
     else:
         return A
 
@@ -2398,31 +2405,30 @@ def rotvelxform_inv_dot(𝚪, 𝚪d, full=False, representation="rpy/xyz"):
 
     elif representation == "exp":
         # autogenerated by symbolic/angvelxform_dot.ipynb
-        sk = smb.skew(𝚪)
-        skd = smb.skew(𝚪d)
+        v = 𝚪
+        vd = 𝚪d
+        sk = smb.skew(v)
+        skd = smb.skew(vd)
         theta_dot = np.inner(𝚪, 𝚪d) / smb.norm(𝚪)
         theta = smb.norm(𝚪)
-        Theta = 1 / theta ** 2 * (1 - theta / 2 * S(theta) / (1 - C(theta)))
+        Theta = (1.0 - theta / 2.0 * np.sin(theta) / (1.0 - np.cos(theta))) / theta**2
 
         # hand optimized version of code from notebook
         # TODO:
         #   results are close but different to numerical cross check
         #   something wrong in the derivation
-        # Theta_dot = (
-        #     -theta * C(theta) - S(theta) + theta * S(theta) ** 2 / (1 - C(theta))
-        # ) * theta_dot / 2 / (1 - C(theta)) / theta**2 - (
-        #     2 - theta * S(theta) / (1 - C(theta))
-        # ) * theta_dot / theta**3
-        Theta_dot = (-1/2*theta*theta_dot*C(theta)/(1 - C(theta)) + (1/2)*theta*theta_dot*S(theta)**2/(1 - C(theta))**2 - 1/2*theta_dot*S(theta)/(1 - C(theta)))/theta**2 - 2*theta_dot*(-1/2*theta*S(theta)/(1 - C(theta)) + 1)/theta**3
+        Theta_dot = (
+            -theta * C(theta) - S(theta) + theta * S(theta) ** 2 / (1 - C(theta))
+        ) * theta_dot / 2 / (1 - C(theta)) / theta**2 - (
+            2 - theta * S(theta) / (1 - C(theta))
+        ) * theta_dot / theta**3
 
         Ainv_dot = -0.5 * skd + 2.0 * sk @ skd * Theta + sk @ sk * Theta_dot
     else:
         raise ValueError("bad representation specified")
 
     if full:
-        result_66 = np.zeros(6,6)
-        result_66[3:,3:] = Ainv_dot
-        return result_66
+        return sp.linalg.block_diag(np.eye(3, 3), Ainv_dot)
     else:
         return Ainv_dot
 
@@ -3059,7 +3065,7 @@ def tranimate(T, **kwargs):
         pass
 
     anim.trplot(T, **kwargs)
-    anim.run(**kwargs)
+    return anim.run(**kwargs)
 
     # plt.show(block=block)
 
@@ -3080,7 +3086,7 @@ if __name__ == "__main__":  # pragma: no cover
         open(
             pathlib.Path(__file__).parent.parent.parent.absolute()
             / "tests"
-            / "smb"
+            / "base"
             / "test_transforms3d.py"
         ).read()
     )  # pylint: disable=exec-used
@@ -3089,7 +3095,7 @@ if __name__ == "__main__":  # pragma: no cover
         open(
             pathlib.Path(__file__).parent.parent.parent.absolute()
             / "tests"
-            / "smb"
+            / "base"
             / "test_transforms3d_plot.py"
         ).read()
     )  # pylint: disable=exec-used
