@@ -581,6 +581,17 @@ def angdiff(a, b=None):
     else:
         return np.mod(a - b + math.pi, 2 * math.pi) - math.pi
 
+def angle_std(v):
+    pass
+
+def angle_mean(v):
+    pass
+
+def angle_wrap(v, how='-mpi_pi'):
+    pass
+
+def angle_diff(v):
+    pass
 
 def removesmall(v, tol=100):
     """
