@@ -205,9 +205,7 @@ class SpatialVector(BasePoseList):
 
         return self.__class__([-x for x in self.data])
 
-    def __add__(
-        left, right
-    ):  # lgtm[py/not-named-self] pylint: disable=no-self-argument
+    def __add__(left, right):  # lgtm[py/not-named-self] pylint: disable=no-self-argument
         """
         Overloaded ``*`` operator (superclass method)
 
@@ -231,9 +229,7 @@ class SpatialVector(BasePoseList):
 
         return left.__class__([x + y for x, y in zip(left.data, right.data)])
 
-    def __sub__(
-        left, right
-    ):  # lgtm[py/not-named-self] pylint: disable=no-self-argument
+    def __sub__(left, right):  # lgtm[py/not-named-self] pylint: disable=no-self-argument
         """
         Overloaded ``-`` operator (superclass method)
 
@@ -256,9 +252,7 @@ class SpatialVector(BasePoseList):
 
         return left.__class__([x - y for x, y in zip(left.data, right.data)])
 
-    def __rmul__(
-        right, left
-    ):  # lgtm[py/not-named-self] pylint: disable=no-self-argument
+    def __rmul__(right, left):  # lgtm[py/not-named-self] pylint: disable=no-self-argument
         """
         Overloaded ``*`` operator (superclass method)
 
@@ -483,13 +477,10 @@ class SpatialForce(SpatialF6):
 
     # n = SpatialForce(val);
 
-    def __rmul__(
-        right, left
-    ):  # lgtm[py/not-named-self] pylint: disable=no-self-argument
+    def __rmul__(right, left):  # lgtm[py/not-named-self] pylint: disable=no-self-argument
         # Twist * SpatialForce -> SpatialForce
         return SpatialForce(left.Ad().T @ right.A)
 
-
 # ------------------------------------------------------------------------- #
 
 
@@ -619,9 +610,7 @@ class SpatialInertia(BasePoseList):
     def __str__(self):
         return str(self.A)
 
-    def __add__(
-        left, right
-    ):  # lgtm[py/not-named-self] pylint: disable=no-self-argument
+    def __add__(left, right):  # lgtm[py/not-named-self] pylint: disable=no-self-argument
         """
         Spatial inertia addition
         :param left:
@@ -636,9 +625,7 @@ class SpatialInertia(BasePoseList):
             raise TypeError("can only add spatial inertia to spatial inertia")
         return SpatialInertia(left.I + left.I)
 
-    def __mul__(
-        left, right
-    ):  # lgtm[py/not-named-self] pylint: disable=no-self-argument
+    def __mul__(left, right):  # lgtm[py/not-named-self] pylint: disable=no-self-argument
         """
         Overloaded ``*`` operator (superclass method)
 
@@ -662,9 +649,7 @@ class SpatialInertia(BasePoseList):
         else:
             raise TypeError("bad postmultiply operands for Inertia *")
 
-    def __rmul__(
-        self, left
-    ):  # lgtm[py/not-named-self] pylint: disable=no-self-argument
+    def __rmul__(right, left):  # lgtm[py/not-named-self] pylint: disable=no-self-argument
         """
         Overloaded ``*`` operator (superclass method)
 
@@ -678,7 +663,7 @@ class SpatialInertia(BasePoseList):
           the SpatialAcceleration ``a``.
         - ``v * I`` is the SpatialMomemtum of a body with SpatialInertia ``I`` and SpatialVelocity ``v``.
         """
-        return self.__mul__(left)
+        return right.__mul__(left)
 
 
 if __name__ == "__main__":
