@@ -9,7 +9,6 @@ from math import pi
 from spatialmath.twist import *
 # from spatialmath import super_pose # as sp
 from spatialmath.base import *
-from spatialmath.base import argcheck
 from spatialmath.baseposematrix import BasePoseMatrix
 from spatialmath.twist import BaseTwist
 
@@ -363,6 +362,7 @@ class Twist2dTest(unittest.TestCase):
 
 # ---------------------------------------------------------------------------------------#
 if __name__ == '__main__':
+    from spatialmath import SE2, Twist2
 
-
+    tw = Twist2( SE2([1, 2, 0]) )
     unittest.main()
